@@ -147,12 +147,12 @@ def RetrieveData(Date, args):
             try:
                 local_filename = os.path.join(output_folder, filename)
                 session = requests.Session()
-                with session.get(url, stream=True) as r:
-                    r.raise_for_status()
-                    with open(local_filename, 'wb') as f:
-                        for chunk in r.iter_content(chunk_size=1024 * 1024):
-                            if chunk:  # filter out keep-alive new chunks
-                                f.write(chunk)
+                r = session.get(url, stream=True)
+                r.raise_for_status()
+                with open(local_filename, 'wb') as f:
+                    for chunk in r.iter_content(chunk_size=1024 * 1024):
+                        if chunk:  # filter out keep-alive new chunks
+                            f.write(chunk)
                
                 no_extract = 0                
             except:
@@ -164,12 +164,12 @@ def RetrieveData(Date, args):
                 
                 local_filename = os.path.join(output_folder, filename2)
                 session = requests.Session()
-                with session.get(url, stream=True) as r:
-                    r.raise_for_status()
-                    with open(local_filename, 'wb') as f:
-                        for chunk in r.iter_content(chunk_size=1024 * 1024):
-                            if chunk:  # filter out keep-alive new chunks
-                                f.write(chunk)
+                r = session.get(url, stream=True)
+                r.raise_for_status()
+                with open(local_filename, 'wb') as f:
+                    for chunk in r.iter_content(chunk_size=1024 * 1024):
+                        if chunk:  # filter out keep-alive new chunks
+                            f.write(chunk)
                 no_extract = 1
             
         try:
