@@ -197,8 +197,10 @@ def Collect_data(TilesHorizontal,TilesVertical,Date,output_folder, band, resolut
 
     # Load accounts
     BEARER = watertools.Functions.Random.Get_Username_PWD.GET('NASA_BEARER')
-
-    s = requests.Session()  
+    username, password = watertools.Functions.Random.Get_Username_PWD.GET('NASA')
+    
+    s = requests.session()
+    
     headers = {
         'Authorization': 'Bearer %s'%BEARER[0]
         }                
@@ -240,7 +242,7 @@ def Collect_data(TilesHorizontal,TilesVertical,Date,output_folder, band, resolut
 
             if not downloaded == 1:
              
-                r = s.get(''.join([url,'?fields=all&format=json']), headers=headers, timeout = 2000)
+                r = s.get(''.join([url,'?fields=all&format=json']), stream=True, headers=headers, timeout = 2000)
                 if r.status_code == 200:            
                     f = r.text 
                 else:
@@ -367,3 +369,34 @@ def Collect_data(TilesHorizontal,TilesVertical,Date,output_folder, band, resolut
     dst_ds = None
     sds = None
     return()
+
+
+class SessionWithHeaderRedirection(requests.Session):
+
+    AUTH_HOST = 'urs.earthdata.nasa.gov'
+
+    def __init__(self, username, password):
+        super().__init__()
+        self.auth = (username, password)
+
+   # Overrides from the library to keep headers when redirected to or from
+   # the NASA auth host.
+
+    def rebuild_auth(self, prepared_request, response):
+
+        headers = prepared_request.headers
+        url = prepared_request.url
+
+        if 'Authorization' in headers:
+            original_parsed = requests.utils.urlparse(response.request.url)
+            redirect_parsed = requests.utils.urlparse(url)
+
+            if (original_parsed.hostname != redirect_parsed.hostname) and \
+                    redirect_parsed.hostname != self.AUTH_HOST and \
+                    original_parsed.hostname != self.AUTH_HOST:
+
+                del headers['Authorization']
+
+
+
+        return()
\ No newline at end of file
